summaryrefslogtreecommitdiffstats
path: root/parameter/FormattedSubsystemObject.h
diff options
context:
space:
mode:
authorSebastien Gonzalve <oznog@zarb.org>2014-02-20 22:28:03 +0100
committerDavid Wagner <david.wagner@intel.com>2014-09-11 14:25:02 +0200
commitd9526499d6ab53b7d13d1434f748f6f2161c2e0a (patch)
tree8d2e2db275800821d4bf8873fc16b686bca60b2d /parameter/FormattedSubsystemObject.h
parentffbf43b383bb8693741430b02c24dbc9b127f7f7 (diff)
downloadexternal_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.zip
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.gz
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.bz2
Remove using std::XXX from headers
This is a bad practice to have using in headers because it pollutes the namespace of any user of that header.
Diffstat (limited to 'parameter/FormattedSubsystemObject.h')
-rw-r--r--parameter/FormattedSubsystemObject.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/parameter/FormattedSubsystemObject.h b/parameter/FormattedSubsystemObject.h
index 2615978..c04583b 100644
--- a/parameter/FormattedSubsystemObject.h
+++ b/parameter/FormattedSubsystemObject.h
@@ -45,24 +45,24 @@ public:
* Builds a new CFormattedSubsystemObject instance, using a simple mapping value without Amends.
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
* @param[in] strFormattedMapping A string corresponding to the mapping of the element. The
* string does not contain any Amend (%) and does not need to be formatted.
*/
CFormattedSubsystemObject(CInstanceConfigurableElement* pInstanceConfigurableElement,
- const string& strFormattedMapping);
+ const std::string& strFormattedMapping);
/**
* Builds a new CFormattedSubsystemObject instance, using a mapping value containing Amends.
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
* @param[in] strMappingValue A string corresponding to the mapping of the element. The
* string contains Amend (%) and needs to be formatted with information from the context.
* @param[in] uiFirstAmendKey Index of the first Amend key
* @param[in] uiNbAmendKeys Number of Amends
* @param[in] context Contains values associated to Amend keys
*/
CFormattedSubsystemObject(CInstanceConfigurableElement* pInstanceConfigurableElement,
- const string& strMappingValue,
+ const std::string& strMappingValue,
uint32_t uiFirstAmendKey,
uint32_t uiNbAmendKeys,
const CMappingContext& context);
@@ -71,9 +71,9 @@ public:
/**
* Returns the formatted mapping value associated to the element.
*
* @return A string containing the mapping
*/
- virtual string getFormattedMappingValue() const;
+ virtual std::string getFormattedMappingValue() const;
private:
@@ -89,24 +89,24 @@ private:
/**
* Generic mapping formatting
*
* Format a string from mapping data and its context, replacing amendments by their value
*
* @param[in] strMappingValue The input mapping string containing amendments
* @param[in] context uiFirstAmendKey The index of the first Amend key in the key list of the
* context
* @param[in] uiNbAmendKeys Number of Amend keys in the context
* @param[in] context The context containing Amend values
*
* @return The formatted string, corresponding to the input strMappingValue where %n have been
* replaced by their value
*/
- static string formatMappingValue(const string& strMappingValue,
+ static std::string formatMappingValue(const std::string& strMappingValue,
uint32_t uiFirstAmendKey,
uint32_t uiNbAmendKeys,
const CMappingContext& context);
/**
* string containing the formatted mapping value
*/
- string _strFormattedMappingValue;
+ std::string _strFormattedMappingValue;
};
@@ -45,24 +45,24 @@ public:
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
- * @param[in] strFormattedMapping A string corresponding to the mapping of the element. The
- * string does not contain any Amend (%) and does not need to be formatted.
+ * @param[in] strFormattedMapping A std::string corresponding to the mapping of the element. The
+ * std::string does not contain any Amend (%) and does not need to be formatted.
*/
CFormattedSubsystemObject(CInstanceConfigurableElement* pInstanceConfigurableElement,
@@ -45,24 +45,24 @@ public:
*
* @param[in] pInstanceConfigurableElement Instance of the element linked to the SubsytemObject.
- * @param[in] strMappingValue A string corresponding to the mapping of the element. The
- * string contains Amend (%) and needs to be formatted with information from the context.
+ * @param[in] strMappingValue A std::string corresponding to the mapping of the element. The
+ * std::string contains Amend (%) and needs to be formatted with information from the context.
* @param[in] uiFirstAmendKey Index of the first Amend key
* @param[in] uiNbAmendKeys Number of Amends
@@ -71,9 +71,9 @@ public:
* Returns the formatted mapping value associated to the element.
*
- * @return A string containing the mapping
+ * @return A std::string containing the mapping
*/
@@ -89,24 +89,24 @@ private:
* Generic mapping formatting
*
- * Format a string from mapping data and its context, replacing amendments by their value
+ * Format a std::string from mapping data and its context, replacing amendments by their value
*
@@ -89,24 +89,24 @@ private:
*
- * @param[in] strMappingValue The input mapping string containing amendments
+ * @param[in] strMappingValue The input mapping std::string containing amendments
* @param[in] context uiFirstAmendKey The index of the first Amend key in the key list of the
* context
@@ -89,24 +89,24 @@ private:
* @param[in] context The context containing Amend values
*
- * @return The formatted string, corresponding to the input strMappingValue where %n have been
+ * @return The formatted std::string, corresponding to the input strMappingValue where %n have been
* replaced by their value
*/
@@ -89,24 +89,24 @@ private:
const CMappingContext& context);
/**
- * string containing the formatted mapping value
+ * std::string containing the formatted mapping value
*/